kenzo: Construct topological spaces and compute homology groups
===============================================================

Description
-----------

Kenzo is a package to compute properties (mainly homology groups) of
topological spaces. It allows defining spaces created from others by
constuctions like loop spaces, classifying spaces and so on.

License
-------

GPL


Upstream Contact
----------------

-  https://github.com/gheber/kenzo

-  https://github.com/miguelmarco/kenzo/

